--- a/accessoryservices/accessoryserver/inc/Common/AccPolAccessoryPolicy.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Common/AccPolAccessoryPolicy.h Wed Oct 13 15:58:37 2010 +0300
@@ -231,12 +231,12 @@
* Detect all subblock capabilities and append them to the given
* array.
*/
- void ParseSubblocksL( const TUint64& aVal, RArray<TUint64>& aCaps );
+ void ParseSubblocks( const TUint64& aVal, RArray<TUint64>& aCaps );
/**
* Detect all subblock names and append them to the given array.
*/
- void ParseNamesL( const TUint32& aVal, RArray<TUint32>& aNames );
+ void ParseNames( const TUint32& aVal, RArray<TUint32>& aNames );
/**
* Find a bit number from bitmask.
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvASYProxyHandler.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvASYProxyHandler.h Wed Oct 13 15:58:37 2010 +0300
@@ -123,7 +123,7 @@
* @return Transaction ID assigned to this operation.
* @see RemoveTransactionID
*/
- TInt StoreTransactionIDL( TProcessCmdId aCmdId,
+ TInt StoreTransactionID( TProcessCmdId aCmdId,
TASYCommandParamRecord& aASYCommand,
TPtr8* aPtrBuf );
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvConnectionHandler.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvConnectionHandler.h Wed Oct 13 15:58:37 2010 +0300
@@ -275,7 +275,7 @@
* During response handling name in question can be retrieved from here
* according to the transaction Id with FindRequestData() method.
*/
- void StoreRequestDataL( TAccPolNameRecord aName,
+ void StoreRequestData( TAccPolNameRecord aName,
TInt aTrId,
TBool aUpdateConnectionNotification );
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvServerModel.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvServerModel.h Wed Oct 13 15:58:37 2010 +0300
@@ -379,7 +379,7 @@
* @param aThreadID ASYs thread ID to be stored.
* @return void
*/
- void AddASYThreadIdL( TUint aThreadID );
+ void AddASYThreadId( TUint aThreadID );
/**
* Creates mapping between Generic ID and ASY.
@@ -391,7 +391,7 @@
* @param aUniqueID Unique identifier of a Generic ID.
* @return void
*/
- void StoreASYThreadIDL( TUint aThreadID, TInt aUniqueID );
+ void StoreASYThreadID( TUint aThreadID, TInt aUniqueID );
/**
* Removes mapping between Generic ID and ASY.
@@ -428,7 +428,7 @@
* @return void
* @see FindAndDeleteMsgThreadIDFilter()
*/
- void SetMsgThreadIDFilterL( TUint aThreadID, TMsgID aMsgID );
+ void SetMsgThreadIDFilter( TUint aThreadID, TMsgID aMsgID );
/**
* Find and delete a Thread Id/message filter.
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvSettingsHandler.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvSettingsHandler.h Wed Oct 13 15:58:37 2010 +0300
@@ -233,7 +233,7 @@
/**
* Returns all static keys for accessory mode.
*/
- void GetStaticKeysL( const TAccMode aAccMode,
+ void GetStaticKeys( const TAccMode aAccMode,
RArray< TUint32 >& aArray ) const;
public: // Data
--- a/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyAsyLoader.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyAsyLoader.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -382,7 +382,7 @@
if ( found == EFalse )
{
- onlyServicesIndexArray.AppendL( i );
+ onlyServicesIndexArray.Append( i );
}
}
@@ -397,7 +397,7 @@
iServiceImplInfoArray.operator[]( onlyServicesIndexArray.operator[]( k ) );
iServiceImplInfoArray.Remove( onlyServicesIndexArray.operator[]( k ) );
- iServiceImplInfoArray.AppendL( implementationInformation );
+ iServiceImplInfoArray.Append( implementationInformation );
}
// Find Service / Handler pairs
@@ -423,7 +423,7 @@
zeroUid.iUid = ZEROHANDLERUID;
while ( iImplUidsHandlerArray.Count() < iServiceImplInfoArray.Count() )
{
- iImplUidsHandlerArray.AppendL( zeroUid );
+ iImplUidsHandlerArray.Append( zeroUid );
}
User::RequestComplete( ptrStat, KErrNone );
--- a/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsService.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsService.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -149,9 +149,6 @@
iAsyProxyCommsStack = 0;
}
- iAsyComms.CloseSubSession();
- iServer.Disconnect();
- iServer.Close();
COM_TRACE_( "[AccFW:AsyProxy] CASYProxyCommsService::~CASYProxyCommsService" );
}
--- a/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsStack.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsStack.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -121,10 +121,8 @@
}
CASYProxyTRRecord* asyProxyTRRecord = CASYProxyTRRecord::NewL( aASYProxyCommandObserver );
- CleanupStack::PushL ( asyProxyTRRecord );
- iTRRecordArray.AppendL( asyProxyTRRecord );
- CleanupStack::Pop(1);
-
+ iTRRecordArray.Append( asyProxyTRRecord );
+
aASYProxyCommandObserver->InitializeRef( asyProxyTRRecord );
aASYProxyCommandObserver->IssueRequestL();
--- a/accessoryservices/accessoryserver/src/ConfigFileParser/AccConfigFileParser.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ConfigFileParser/AccConfigFileParser.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -50,15 +50,15 @@
// ============================ MEMBER FUNCTIONS ===============================
// -----------------------------------------------------------------------------
-// CAccConfigFileParser::ParseSubblocksL
+// CAccConfigFileParser::ParseSubblocks
// Detecting subblocks and store them to destination array
// (other items were commented in a header).
// -----------------------------------------------------------------------------
//
-void CAccConfigFileParser::ParseSubblocksL( const TUint64& aVal,
+void CAccConfigFileParser::ParseSubblocks( const TUint64& aVal,
RArray<TUint64>& aCaps )
{
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL()" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks()" );
TUint64 sum( 0 );
TUint64 curVal( 1 );
@@ -72,7 +72,7 @@
if ( ( curVal & aVal ) == curVal )
{
COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::(Cap) MATCH! HI:0x%x LO:0x%x", I64HIGH( curVal ), I64LOW( curVal ) );
- aCaps.AppendL( curVal ); // Append to found caps array
+ aCaps.Append( curVal ); // Append to found caps array
sum += curVal;
}
curBit++;
@@ -80,32 +80,32 @@
}
while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL - return void" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks - return void" );
}
// -----------------------------------------------------------------------------
-// CAccConfigFileParser::ParseNamesL
+// CAccConfigFileParser::ParseNames
// Detect all subblock names and append them to the gicen array.
// (other items were commented in a header).
// -----------------------------------------------------------------------------
//
-void CAccConfigFileParser::ParseNamesL( const TUint32& aVal,
+void CAccConfigFileParser::ParseNames( const TUint32& aVal,
RArray<TUint32>& aNames )
{
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL()" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames()" );
TUint32 sum( 0 );
TUint32 curVal( 1 );
TInt curBit( 0 );
do {
- COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
- COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL & 0x%x", curVal & aVal );
+ COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
+ COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames & 0x%x", curVal & aVal );
// Check if this subblock is defined in SB-def block
if ( ( curVal & aVal ) == curVal )
{
COM_TRACE_1( "[AccFW:SrvUtil] (Name) MATCH! 0x%x",curVal );
- aNames.AppendL( curVal ); // Append to found caps array
+ aNames.Append( curVal ); // Append to found caps array
sum += curVal;
}
curBit++;
@@ -113,7 +113,7 @@
}
while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL - return void" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames - return void" );
}
// -----------------------------------------------------------------------------
--- a/accessoryservices/accessoryserver/src/Policy/AccPolAccessoryPolicy.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Policy/AccPolAccessoryPolicy.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -819,7 +819,7 @@
TAccPolGenericIDAccessor::SetFeatureAttributeL(
genericID, KAccPolSBCapabilities, valU64 );
- ParseSubblocksL( valU64, foundCapabilityGroups );
+ ParseSubblocks( valU64, foundCapabilityGroups );
//set "values" to point to firts value
TLex8 values;
@@ -871,7 +871,7 @@
TUint32 capabilityGroupValue(0);
lVal.Val( capabilityGroupValue, EDecimal );
- ParseNamesL( capabilityGroupValue, foundCapability );
+ ParseNames( capabilityGroupValue, foundCapability );
TInt capabilityIter(0);
TInt foundCapabilityCount( foundCapability.Count() );
@@ -970,7 +970,7 @@
value,
( TAccPolValueType )type,
( TAccPolValueLocation )location );
- nameValueArray.AppendL( nameValueRecord );
+ nameValueArray.Append( nameValueRecord );
}
++capabilityIter;
}
@@ -1004,14 +1004,14 @@
}
// -----------------------------------------------------------------------------
-// CAccPolAccessoryPolicy::ParseSubblocksL
+// CAccPolAccessoryPolicy::ParseSubblocks
// Detecting subblocks and store them to destination array
// (other items were commented in a header).
// -----------------------------------------------------------------------------
//
-void CAccPolAccessoryPolicy::ParseSubblocksL( const TUint64& aVal, RArray<TUint64>& aCaps )
+void CAccPolAccessoryPolicy::ParseSubblocks( const TUint64& aVal, RArray<TUint64>& aCaps )
{
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL()" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks()" );
TUint64 sum( 0 );
TUint64 curVal( 1 );
@@ -1025,7 +1025,7 @@
if ( ( curVal & aVal ) == curVal )
{
COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::(Cap) MATCH! HI:0x%x LO:0x%x", I64HIGH( curVal ), I64LOW( curVal ) );
- aCaps.AppendL( curVal ); // Append to found caps array
+ aCaps.Append( curVal ); // Append to found caps array
sum += curVal;
}
curBit++;
@@ -1033,31 +1033,31 @@
}
while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL - return void" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks - return void" );
}
// -----------------------------------------------------------------------------
-// CAccPolAccessoryPolicy::ParseNamesL
+// CAccPolAccessoryPolicy::ParseNames
// Detect all subblock names and append them to the gicen array.
// (other items were commented in a header).
// -----------------------------------------------------------------------------
//
-void CAccPolAccessoryPolicy::ParseNamesL( const TUint32& aVal, RArray<TUint32>& aNames )
+void CAccPolAccessoryPolicy::ParseNames( const TUint32& aVal, RArray<TUint32>& aNames )
{
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL()" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames()" );
TUint32 sum( 0 );
TUint32 curVal( 1 );
TInt curBit( 0 );
do {
- COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
- COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL & 0x%x", curVal & aVal );
+ COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
+ COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames & 0x%x", curVal & aVal );
// Check if this subblock is defined in SB-def block
if ( ( curVal & aVal ) == curVal )
{
COM_TRACE_1( "[AccFW:SrvUtil] (Name) MATCH! 0x%x",curVal );
- aNames.AppendL( curVal ); // Append to found caps array
+ aNames.Append( curVal ); // Append to found caps array
sum += curVal;
}
curBit++;
@@ -1065,7 +1065,7 @@
}
while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
- COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL - return void" );
+ COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames - return void" );
}
// -----------------------------------------------------------------------------
--- a/accessoryservices/accessoryserver/src/Server/AccSrvASYProxyHandler.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvASYProxyHandler.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -127,7 +127,7 @@
}
else
{
- trID = StoreTransactionIDL( aCmdId, aASYCommand, aPtrBuf );
+ trID = StoreTransactionID( aCmdId, aASYCommand, aPtrBuf );
}
COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::HandleASYCommsL - return TrID=%d", trID );
@@ -135,22 +135,22 @@
}
// -----------------------------------------------------------------------------
-// CAccSrvASYProxyHandler::StoreTransactionIDL
+// CAccSrvASYProxyHandler::StoreTransactionID
// -----------------------------------------------------------------------------
//
-TInt CAccSrvASYProxyHandler::StoreTransactionIDL(
+TInt CAccSrvASYProxyHandler::StoreTransactionID(
TProcessCmdId aCmdId,
TASYCommandParamRecord& aASYCommand,
TPtr8* aPtrBuf )
{
- COM_TRACE_( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL()" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID()" );
TInt trID( KErrNotFound );
TInt count( iOngoingTransactions.Count() );
TUint32 nameFromOngoingTransactions;
TUint32 nameFromRequest;
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - current count = %d", count );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - current count = %d", count );
for ( TInt i( 0 ); i < count; ++i )
{
@@ -163,7 +163,7 @@
{
//Same command is under processing in ASY -> use existing trid
trID = iOngoingTransactions.operator[](i).iTransactionID;
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - found trid = %d", trID );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - found trid = %d", trID );
break;
}
else
@@ -180,7 +180,7 @@
trIDRecord.iNameRecord = aASYCommand.iNameRecord;
trIDRecord.iCommand = aASYCommand.iCmdValue;
trIDRecord.iTransactionID = trID;
- iOngoingTransactions.AppendL( trIDRecord );
+ iOngoingTransactions.Append( trIDRecord );
//Complete outstanding NotifyProcessCommand()
TRAP_IGNORE( iConnectionController->NotificationQueue().CompleteASYCmdL(
@@ -196,7 +196,7 @@
//This means also that ASY is not informed about this command.
}
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - return %d", trID );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - return %d", trID );
return trID;
}
@@ -217,7 +217,7 @@
if ( iOngoingTransactions.operator[]( i ).iTransactionID == aTransactionID )
{
iOngoingTransactions.Remove( i );
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - removed index = %d",i );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - removed index = %d",i );
break;
}
else
--- a/accessoryservices/accessoryserver/src/Server/AccSrvConnectionController.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvConnectionController.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -277,7 +277,7 @@
COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionController::HandleConnectL() New connection" );
// Store ThreadId for ASY handling
- iServerModel->StoreASYThreadIDL( aCallerThreadID, aGenericID.UniqueID() );
+ iServerModel->StoreASYThreadID( aCallerThreadID, aGenericID.UniqueID() );
iServerModel->AddPhysicalConnectionL( aGenericID );
--- a/accessoryservices/accessoryserver/src/Server/AccSrvConnectionHandler.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvConnectionHandler.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -148,7 +148,7 @@
//Stored request data is used when response is received from ASY
//(i.e. HandleValueMessageL)
- StoreRequestDataL( asyCommandParamRecord.iNameRecord, trId, ETrue );
+ StoreRequestData( asyCommandParamRecord.iNameRecord, trId, ETrue );
//Store this object to queue to be able to receive response from ASY
iCallback->RegisterControlMessageL( ESetValue, this );
@@ -613,30 +613,30 @@
//Stored request data is used when response is received from ASY
//(i.e. HandleValueMessageL)
- StoreRequestDataL( aASYCommandParam.iNameRecord, trId, EFalse );
+ StoreRequestData( aASYCommandParam.iNameRecord, trId, EFalse );
//Store this object to queue to be able to receive response from ASY
iCallback-> RegisterControlMessageL( EGetValue, this );
}
// -----------------------------------------------------------------------------
-// CAccSrvConnectionHandler::StoreRequestDataL
+// CAccSrvConnectionHandler::StoreRequestData
// -----------------------------------------------------------------------------
//
-void CAccSrvConnectionHandler::StoreRequestDataL( TAccPolNameRecord aName,
+void CAccSrvConnectionHandler::StoreRequestData( TAccPolNameRecord aName,
TInt aTrId,
TBool aUpdateConnectionNotification )
{
- COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestDataL()" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestData()" );
TAccSrvRequestData requestData;
requestData.iName = aName;
requestData.iTrId = aTrId;
requestData.iUpdateNotification = aUpdateConnectionNotification;
- iRequestDataArray.AppendL( requestData );
+ iRequestDataArray.Append( requestData );
- COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestDataL - return void" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestData - return void" );
}
// -----------------------------------------------------------------------------
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSettingsHandler.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSettingsHandler.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -453,7 +453,7 @@
RArray< TUint32 > array;
CleanupClosePushL( array );
- GetStaticKeysL( aAccMode, array );
+ GetStaticKeys( aAccMode, array );
TAccModeSetting setting;
// get mode related static settings for client
@@ -899,45 +899,45 @@
}
// -----------------------------------------------------------------------------
-// CAccSrvSettingsHandler::GetStaticKeysL
+// CAccSrvSettingsHandler::GetStaticKeys
//
// (other items were commented in a header).
// -----------------------------------------------------------------------------
//
-void CAccSrvSettingsHandler::GetStaticKeysL(
+void CAccSrvSettingsHandler::GetStaticKeys(
const TAccMode aAccMode,
RArray< TUint32 >& aArray ) const
{
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeysL(%d)", aAccMode );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeys(%d)", aAccMode );
switch( aAccMode )
{
case EAccModeWiredHeadset:
- aArray.AppendL( KAccServerWiredHSLights );
+ aArray.Append( KAccServerWiredHSLights );
break;
case EAccModeWirelessHeadset:
- aArray.AppendL( KAccServerWirelessHSLights );
+ aArray.Append( KAccServerWirelessHSLights );
break;
case EAccModeWiredCarKit:
- aArray.AppendL( KAccServerWiredCarKitLights );
+ aArray.Append( KAccServerWiredCarKitLights );
break;
case EAccModeWirelessCarKit:
- aArray.AppendL( KAccServerWirelessCarKitLights );
+ aArray.Append( KAccServerWirelessCarKitLights );
break;
case EAccModeTextDevice:
- aArray.AppendL( KAccServerTextDeviceLights );
+ aArray.Append( KAccServerTextDeviceLights );
break;
case EAccModeLoopset:
- aArray.AppendL( KAccServerLoopsetLights );
+ aArray.Append( KAccServerLoopsetLights );
break;
case EAccModeMusicStand:
- aArray.AppendL( KAccServerMusicStandLights );
+ aArray.Append( KAccServerMusicStandLights );
break;
default: // mode is not supported
break;
}
- COM_TRACE_( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeysL() returns" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeys() returns" );
}
// ========================== OTHER EXPORTED FUNCTIONS =========================
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSubAsyComms.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSubAsyComms.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -82,7 +82,7 @@
COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAsyComms::ConstructL()" );
iInitCommandTimer = CAccSrvProcessCommandTimer::NewL( this, KInitCmdTimeOut );
- iServerModel->AddASYThreadIdL( iASYThreadID );
+ iServerModel->AddASYThreadId( iASYThreadID );
COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAsyComms::ConstructL - return void" );
}
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSubControl.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSubControl.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -235,18 +235,12 @@
}
else
{
- TPckg<TInt>iReplyPck(0);
- TRequestStatus iStatus =KRequestPending;
- notifier.StartNotifierAndGetResponse(iStatus,
- KAccFwUiNoteNotifierUid,
- KNullDesC8,iReplyPck);
- User::WaitForRequest(iStatus);
- err = iStatus.Int();
- if(KErrNone != err)
- {
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvSubControl::ConnectAccessoryL - Couldn't start notifier: err = %d", err);
- }
- notifier.Close();
+ err = notifier.StartNotifier( KAccFwUiNoteNotifierUid, KNullDesC8 );
+ if ( err != KErrNone )
+ {
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvSubControl::ConnectAccessoryL - Couldn't start notifier: err = %d", err);
+ }
+ notifier.Close();
}
}
else
--- a/accessoryservices/remotecontrolfw/server/inc/session.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/remotecontrolfw/server/inc/session.h Wed Oct 13 15:58:37 2010 +0300
@@ -328,6 +328,7 @@
TRemConSessionSending iSending;
+ TBool iInGetConnectionsProcedure;
};
// Inlines
--- a/accessoryservices/remotecontrolfw/server/src/server.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/remotecontrolfw/server/src/server.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -2562,20 +2562,20 @@
void CRemConServer::LogOutgoingRspPendingTsp() const
{
- LOG(_L("Logging outgoing pending TSP commands"));
+ LOG(_L("Logging outgoing pending TSP responses"));
FTRACE(const_cast<CRemConServer*>(this)->OutgoingRspPendingTsp().LogQueue();)
}
void CRemConServer::LogOutgoingPendingSend() const
{
- LOG(_L("Logging outgoing pending send commands"));
+ LOG(_L("Logging outgoing pending send"));
FTRACE(const_cast<CRemConServer*>(this)->OutgoingPendingSend().LogQueue();)
}
void CRemConServer::LogOutgoingSent() const
{
- LOG(_L("Logging outgoing sent commands"));
+ LOG(_L("Logging outgoing sent"));
FTRACE(const_cast<CRemConServer*>(this)->OutgoingSent().LogQueue();)
}
@@ -2587,25 +2587,25 @@
void CRemConServer::LogIncomingNotifyCmdPendingAddress() const
{
- LOG(_L("Logging incoming pending address commands"));
+ LOG(_L("Logging incoming pending address notify commands"));
FTRACE(const_cast<CRemConServer*>(this)->IncomingNotifyCmdPendingAddress().LogQueue();)
}
void CRemConServer::LogIncomingNotifyCmdPendingReAddress() const
{
- LOG(_L("Logging incoming pending address commands"));
+ LOG(_L("Logging incoming pending readdress notify commands"));
FTRACE(const_cast<CRemConServer*>(this)->IncomingNotifyCmdPendingReAddress().LogQueue();)
}
void CRemConServer::LogIncomingPendingDelivery() const
{
- LOG(_L("Logging incoming pending delivery messages"));
+ LOG(_L("Logging incoming pending delivery"));
FTRACE(const_cast<CRemConServer*>(this)->IncomingPendingDelivery().LogQueue();)
}
void CRemConServer::LogIncomingDelivered() const
{
- LOG(_L("Logging incoming delivered commands"));
+ LOG(_L("Logging incoming delivered"));
FTRACE(const_cast<CRemConServer*>(this)->IncomingDelivered().LogQueue();)
}
#endif // __FLOG_ACTIVE
--- a/accessoryservices/remotecontrolfw/server/src/session.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/remotecontrolfw/server/src/session.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -1351,6 +1351,7 @@
if ( err == KErrNone )
{
iServer.SetConnectionHistoryPointer(Id());
+ iInGetConnectionsProcedure = ETrue;
}
CompleteClient(aMessage, err);
}
@@ -1368,6 +1369,8 @@
return;
}
+ iInGetConnectionsProcedure = EFalse;
+
// Get the array of connections at the point in the history we're
// interested in and write it back to the client. NB This is not
// necessarily the Last item in the history but the item that we were
@@ -1569,13 +1572,17 @@
void CRemConSession::ConnectionsChanged()
{
LOG_FUNC;
-
+
+ LOG1(_L("\tiInGetConnectionsProcedure = %d"), iInGetConnectionsProcedure);
+ // Only update the connections history pointer if we're not in the middle
+ // of a 'GetConnections' procedure.
+ if ( !iInGetConnectionsProcedure )
+ {
+ iServer.SetConnectionHistoryPointer(Id());
+ }
LOG1(_L("\tiNotifyConnectionsChangeMsg.Handle = %d"), iNotifyConnectionsChangeMsg.Handle());
if ( iNotifyConnectionsChangeMsg.Handle() )
{
- // Set the connection history pointer to point to the latest item and then complete the
- // NotifyConnectionChange request of the client.
- iServer.SetConnectionHistoryPointer(Id());
CompleteClient(iNotifyConnectionsChangeMsg, KErrNone);
}
}
--- a/commonservices/commonengine/config/export.mk Wed Sep 15 13:36:47 2010 +0300
+++ b/commonservices/commonengine/config/export.mk Wed Oct 13 15:58:37 2010 +0300
@@ -1,5 +1,5 @@
#
-# Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+# Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# This component and the accompanying materials are made available
# under the terms of "Eclipse Public License v1.0"
@@ -17,11 +17,11 @@
# commonengine's actual configuration export makefile
-MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/commonservices/commonengine/config/export.mk
+MAKEFILE = /sf/os/devicesrv/commonservices/commonengine/config/export.mk
$(call push,MAKEFILE_STACK,$(MAKEFILE))
-CONFFILES = $(MAKEFILEDIR)../conf/commonengine.confml $(EPOCROOT)/epoc32/rom/config/confml_data/s60/ \
- $(MAKEFILEDIR)../conf/commonengine_1020503B.crml $(EPOCROOT)/epoc32/rom/config/confml_data/s60/
+CONFFILES = $(MAKEFILEDIR)../conf/commonengine.confml /epoc32/rom/config/confml_data/s60/ \
+ $(MAKEFILEDIR)../conf/commonengine_1020503B.crml /epoc32/rom/config/confml_data/s60/
commonengine_config :: commonengine_config-conf
commonengine_config-conf ::
--- a/commonservices/commonengine/makefile Wed Sep 15 13:36:47 2010 +0300
+++ b/commonservices/commonengine/makefile Wed Oct 13 15:58:37 2010 +0300
@@ -2,7 +2,7 @@
#Define this platform as default if nothing is defined
-MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/commonservices/commonengine/makefile
+MAKEFILE = /sf/os/devicesrv/commonservices/commonengine/makefile
commonengine_all :: commonengine_config
--- a/devicesrv_plat/configuration_file_parser_api/inc/AccConfigFileParser.h Wed Sep 15 13:36:47 2010 +0300
+++ b/devicesrv_plat/configuration_file_parser_api/inc/AccConfigFileParser.h Wed Oct 13 15:58:37 2010 +0300
@@ -143,12 +143,12 @@
* Detect all subblock capabilities and append them to the given
* array.
*/
- void ParseSubblocksL( const TUint64& aVal, RArray<TUint64>& aCaps );
+ void ParseSubblocks( const TUint64& aVal, RArray<TUint64>& aCaps );
/**
* Detect all subblock names and append them to the given array.
*/
- void ParseNamesL( const TUint32& aVal, RArray<TUint32>& aNames );
+ void ParseNames( const TUint32& aVal, RArray<TUint32>& aNames );
/**
* Find a bit number from bitmask.
--- a/devicesrv_pub/common_platform_security_definitions_api/config/export.mk Wed Sep 15 13:36:47 2010 +0300
+++ b/devicesrv_pub/common_platform_security_definitions_api/config/export.mk Wed Oct 13 15:58:37 2010 +0300
@@ -1,5 +1,5 @@
#
-# Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+# Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# This component and the accompanying materials are made available
# under the terms of "Eclipse Public License v1.0"
@@ -18,14 +18,14 @@
# common_platform_security_definitions_api's actual configuration export makefile
-MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/config/export.mk
+MAKEFILE = /sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/config/export.mk
$(call push,MAKEFILE_STACK,$(MAKEFILE))
-INCFILES = $(MAKEFILEDIR)../inc/data_caging_path_literals.hrh $(EPOCROOT)/epoc32/include/ \
- $(MAKEFILEDIR)../inc/data_caging_paths_for_iby.hrh $(EPOCROOT)/epoc32/include/ \
- $(MAKEFILEDIR)../inc/data_caging_paths.hrh $(EPOCROOT)/epoc32/include/ \
- $(MAKEFILEDIR)../inc/data_caging_paths_strings.hrh $(EPOCROOT)/epoc32/include/ \
- $(MAKEFILEDIR)../inc/data_caged_locations.mk $(EPOCROOT)/epoc32/include/
+INCFILES = $(MAKEFILEDIR)../inc/data_caging_path_literals.hrh /epoc32/include/ \
+ $(MAKEFILEDIR)../inc/data_caging_paths_for_iby.hrh /epoc32/include/ \
+ $(MAKEFILEDIR)../inc/data_caging_paths.hrh /epoc32/include/ \
+ $(MAKEFILEDIR)../inc/data_caging_paths_strings.hrh /epoc32/include/ \
+ $(MAKEFILEDIR)../inc/data_caged_locations.mk /epoc32/include/
common_platform_security_config :: common_platform_security_config-inc
--- a/devicesrv_pub/common_platform_security_definitions_api/makefile Wed Sep 15 13:36:47 2010 +0300
+++ b/devicesrv_pub/common_platform_security_definitions_api/makefile Wed Oct 13 15:58:37 2010 +0300
@@ -2,7 +2,7 @@
#Define this platform as default if nothing is defined
-MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/makefile
+MAKEFILE = /sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/makefile
common_platform_security_all :: common_platform_security_config
--- a/devicesrv_pub/platform_path_definitions_api/config/export.mk Wed Sep 15 13:36:47 2010 +0300
+++ b/devicesrv_pub/platform_path_definitions_api/config/export.mk Wed Oct 13 15:58:37 2010 +0300
@@ -1,5 +1,5 @@
#
-# Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+# Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# This component and the accompanying materials are made available
# under the terms of "Eclipse Public License v1.0"
@@ -18,12 +18,12 @@
# platform_path_definitions_api's actual configuration export makefile
-MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/config/export.mk
+MAKEFILE = /sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/config/export.mk
$(call push,MAKEFILE_STACK,$(MAKEFILE))
-INCFILES = $(MAKEFILEDIR)../inc/platform_paths.hrh $(EPOCROOT)/epoc32/include/ \
- $(MAKEFILEDIR)../inc/non_foundation_paths.hrh $(EPOCROOT)/epoc32/include/ \
- $(MAKEFILEDIR)../inc/iconlocations.hrh $(EPOCROOT)/epoc32/include/
+INCFILES = $(MAKEFILEDIR)../inc/platform_paths.hrh /epoc32/include/ \
+ $(MAKEFILEDIR)../inc/non_foundation_paths.hrh /epoc32/include/ \
+ $(MAKEFILEDIR)../inc/iconlocations.hrh /epoc32/include/
platform_path_config :: platform_path_config-inc
platform_path_config-inc ::
--- a/devicesrv_pub/platform_path_definitions_api/makefile Wed Sep 15 13:36:47 2010 +0300
+++ b/devicesrv_pub/platform_path_definitions_api/makefile Wed Oct 13 15:58:37 2010 +0300
@@ -2,7 +2,7 @@
#Define this platform as default if nothing is defined
-MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/makefile
+MAKEFILE = /sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/makefile
platform_path_all :: platform_path_config
--- a/devicesrv_pub/sensor_definitions_api/inc/sensrvilluminationsensor.h Wed Sep 15 13:36:47 2010 +0300
+++ b/devicesrv_pub/sensor_definitions_api/inc/sensrvilluminationsensor.h Wed Oct 13 15:58:37 2010 +0300
@@ -46,17 +46,12 @@
* Brighness constants for ambien light sensor data channel.
*/
static const TUint8 KAmbientLightVeryDark = 0;
- static const TUint8 KAmbientLightDark = 20;
+ static const TUint8 KAmbientLightDark = 20;
static const TUint8 KAmbientLightTwilight = 40;
static const TUint8 KAmbientLightLight = 60;
static const TUint8 KAmbientLightBright = 80;
- static const TUint8 KAmbientLightCloudy = 85;
- static const TUint8 KAmbientLightCloudySunny= 90;
static const TUint8 KAmbientLightSunny = 100;
-
-
-
/**
* Channel data type Id number
*/
--- a/resourcemgmt/hwresourcesmgr/server/inc/HWRMPluginHandler.h Wed Sep 15 13:36:47 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/inc/HWRMPluginHandler.h Wed Oct 13 15:58:37 2010 +0300
@@ -148,7 +148,7 @@
*
* @param aCallback The indication handler to be registered
*/
- void RegisterForIndicationsL(MHWRMIndicationHandler* aCallback);
+ void RegisterForIndications(MHWRMIndicationHandler* aCallback);
/**
* Deregisters handlers for receiving HWRM plug-in indications
--- a/resourcemgmt/hwresourcesmgr/server/src/HWRMPluginHandler.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/src/HWRMPluginHandler.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -328,11 +328,11 @@
// Registers a handler for receiving HWRM plug-in indications
// -----------------------------------------------------------------------------
//
-void CHWRMPluginHandler::RegisterForIndicationsL(MHWRMIndicationHandler* aCallback)
+void CHWRMPluginHandler::RegisterForIndications(MHWRMIndicationHandler* aCallback)
{
COMPONENT_TRACE2( _L( "HWRM Server - CHWRMPluginHandler::RegisterForIndications(), Count() = %d" ), iIndicationCallbacks.Count() );
- iIndicationCallbacks.AppendL(aCallback);
+ iIndicationCallbacks.Append(aCallback);
}
// -----------------------------------------------------------------------------
--- a/resourcemgmt/hwresourcesmgr/server/src/HWRMPowerCommonData.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/src/HWRMPowerCommonData.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -113,7 +113,7 @@
COMPONENT_TRACE2(_L( "HWRM Server - CHWRMPowerCommonData::ConstructL - iMaximumReportingPeriod: %d" ), iMaximumReportingPeriod );
// Register for indications from HWRM plugin.
- aPluginHandler->RegisterForIndicationsL(this);
+ aPluginHandler->RegisterForIndications(this);
iPowerService = CHWRMPowerService::NewL(aPluginHandler, *this);
--- a/resourcemgmt/hwresourcesmgr/server/src/HWRMServer.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/src/HWRMServer.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -737,12 +737,12 @@
iFmTxCommonData = NULL;
iFmTxCommonData = CHWRMFmTxCommonData::NewL();
- iFmTxPluginHandler->RegisterForIndicationsL(iFmTxCommonData);
+ iFmTxPluginHandler->RegisterForIndications(iFmTxCommonData);
iFmTxStateUtility = CHWRMFmTxStateUtility::NewL(iFmTxPluginHandler,
iFmTxWatcherPluginHandler, iFmTxReservationHandler, iFmTxCommonData);
- iFmTxWatcherPluginHandler->RegisterForIndicationsL(iFmTxStateUtility);
+ iFmTxWatcherPluginHandler->RegisterForIndications(iFmTxStateUtility);
}
else
{
--- a/sensorservices/orientationssy/src/SsyOrientation.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/sensorservices/orientationssy/src/SsyOrientation.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -921,7 +921,7 @@
{
User::Leave( KErrNotFound );
}
-
+ iCurrentOrientationState.iDeviceOrientation = TSensrvOrientationData::EOrientationUndefined;
iSensorChannel->CloseChannel();
iChannel = NULL;
@@ -962,7 +962,7 @@
{
User::Leave( KErrNotFound );
}
-
+ iCurrentOrientationState.iDeviceOrientation = TSensrvOrientationData::EOrientationUndefined;
iSensorChannel->StopDataListening();
iChannel = NULL;
--- a/sysstatemgmt/ssmcmdlists/data/noncriticalswpcmdlists.rss Wed Sep 15 13:36:47 2010 +0300
+++ b/sysstatemgmt/ssmcmdlists/data/noncriticalswpcmdlists.rss Wed Oct 13 15:58:37 2010 +0300
@@ -68,46 +68,46 @@
{
// prio 0xFFF1
r_cmd_publishswp,
- // prio 0x7FF2
- r_cmd_activitymonscreensaver, //RSHI-85E4P2
- // prio 0x7FF1
- r_cmd_screensaver, //RSHI-85E4P2
// prio 0x7EFF
- r_cmd_activitymonlogs,
+ r_cmd_activitymonitor1,
// prio 0x7EFE
r_cmd_logs,
// prio 0x7EFD
- r_cmd_activitymonpbk2,
+ r_cmd_activitymonitor2,
// prio 0x7EFC
r_cmd_pbk2,
// prio 0x7EFB
- r_cmd_activitymonmce,
+ r_cmd_activitymonitor3,
// prio 0x7EFA
r_cmd_mce,
// prio 0x7EF9
- r_cmd_activitymonclock,
+ r_cmd_activitymonitor4,
// prio 0x7EF8
r_cmd_clock, //ESLT-842J9W
// prio 0x7EF7
- r_cmd_activitymonvideocenter,
+ r_cmd_activitymonitor5,
// prio 0x7EF6
r_cmd_videocenter,
// prio 0x7EF5
- r_cmd_activitymoniaupdatebg,
+ r_cmd_activitymonitor6,
// prio 0x7EF4
r_cmd_iaupdatebg,
+ // prio 0x7EF3
+ r_cmd_activitymonitor7,
+ // prio 0x7EF2
+ r_cmd_screensaver,
// prio 0x7EEF
- r_cmd_activitymonautosync,
+ r_cmd_activitymonitor8,
// prio 0x7EEE
r_cmd_autosync
#ifdef FF_ATT_ADDRESS_BK
//prio 0x7EEA
- ,r_cmd_activitymonaab,
+ ,r_cmd_activitymonitor9,
//prio 0x7EE9
r_cmd_aab
#endif
// prio 0x7EE8
- ,r_cmd_activitymoncalendar,
+ ,r_cmd_activitymonitor10,
// prio 0x7EE7
r_cmd_calendar //CR:MMUN-82ZHAD
};
@@ -129,10 +129,10 @@
#endif
// ---------------------------------------------------------------------------
-// r_cmd_activitymonlogs
+// r_cmd_activitymonitor1
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonlogs
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor1
{
priority = 0x7EFF;
severity = ECmdCriticalSeverity;
@@ -144,10 +144,10 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonpbk2
+// r_cmd_activitymonitor2
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonpbk2
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor2
{
priority = 0x7EFD;
severity = ECmdCriticalSeverity;
@@ -159,10 +159,10 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonmce
+// r_cmd_activitymonitor3
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonmce
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor3
{
priority = 0x7EFB;
severity = ECmdCriticalSeverity;
@@ -174,10 +174,10 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonclock
+// r_cmd_activitymonitor4
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonclock
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor4
{
priority = 0x7EF9;
severity = ECmdCriticalSeverity;
@@ -189,10 +189,10 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonvideocenter
+// r_cmd_activitymonitor5
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonvideocenter
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor5
{
priority = 0x7EF7;
severity = ECmdCriticalSeverity;
@@ -204,10 +204,10 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymoniaupdatebg
+// r_cmd_activitymonitor6
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymoniaupdatebg
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor6
{
priority = 0x7EF5;
severity = ECmdCriticalSeverity;
@@ -219,12 +219,12 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonscreensaver
+// r_cmd_activitymonitor7
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonscreensaver
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor7
{
- priority = 0x7FF2;
+ priority = 0x7EF3;
severity = ECmdCriticalSeverity;
execution_behaviour = ESsmWaitForSignal;
dllname = "ssmactivitycmd.dll";
@@ -234,10 +234,10 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonautosync
+// r_cmd_activitymonitor8
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonautosync
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor8
{
priority = 0x7EEF;
severity = ECmdCriticalSeverity;
@@ -249,11 +249,11 @@
}
// ---------------------------------------------------------------------------
-// r_cmd_activitymonaab
+// r_cmd_activitymonitor9
// ---------------------------------------------------------------------------
//
#ifdef FF_ATT_ADDRESS_BK
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonaab
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor9
{
priority = 0x7EEA;
severity = ECmdCriticalSeverity;
@@ -266,10 +266,10 @@
#endif
// ---------------------------------------------------------------------------
-// r_cmd_activitymoncalendar
+// r_cmd_activitymonitor10
// ---------------------------------------------------------------------------
//
-RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymoncalendar
+RESOURCE SSM_START_CUSTOM_COMMAND r_cmd_activitymonitor10
{
priority = 0x7EE8;
severity = ECmdCriticalSeverity;
@@ -386,7 +386,7 @@
//
RESOURCE SSM_START_APP_INFO r_cmd_screensaver
{
- priority = 0x7FF1;
+ priority = 0x7EF2;
name = "z:\\sys\\bin\\screensaver.exe";
background = 1; // To background
execution_behaviour = ESsmWaitForSignal;
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvSubAudioControl.h Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvSubAudioControl.h Wed Oct 13 15:58:37 2010 +0300
@@ -112,24 +112,24 @@
private: // New functions
/**
* Handles NotifyAccessoryAudioLinkOpenedL() client request.
* If leave occurs, the client request is completed with that error code.
*
* @since S60 3.1
* @param aMessage Client request.
* @return void
*/
- void NotifyAccessoryAudioLinkOpenedL( const RMessage2& aMessage );
+ void NotifyAccessoryAudioLinkOpened( const RMessage2& aMessage );
/**
* Handles NotifyAccessoryAudioLinkClosedL() client request.
* If leave occurs, the client request is completed with that error code.
*
* @since S60 3.1
* @param aMessage Client request.
* @return void
*/
- void NotifyAccessoryAudioLinkClosedL( const RMessage2& aMessage );
+ void NotifyAccessoryAudioLinkClosed( const RMessage2& aMessage );
/**
* Handles AccessoryAudioLinkOpen() client request.
@@ -182,7 +182,7 @@
void CancelAccessoryAudioLinkClose( const RMessage2& aMessage );
/**
* Handles NotifyAccessoryAudioLinkOpenedL() client request.
* If leave occurs, the client request is completed with that error code.
*
* @since S60 3.1
@@ -192,7 +192,7 @@
void CancelNotifyAccessoryAudioLinkOpened( const RMessage2& aMessage );
/**
* Handles NotifyAccessoryAudioLinkClosedL() client request.
* If leave occurs, the client request is completed with that error code.
*
* @since S60 3.1
@@ -213,10 +213,10 @@
//Stored AccessoryAudioLinkClose() client request for later completion.
RMessage2 iAccessoryAudioLinkCloseMsg;
//Stored NotifyAccessoryAudioLinkOpenedL() client request for later completion.
RMessage2 iNotifyAccessoryAudioLinkOpenedMsg;
//Stored NotifyAccessoryAudioLinkClosedL() client request for later completion.
RMessage2 iNotifyAccessoryAudioLinkClosedMsg;
//Thread id of the client-side caller for this subsession
@@ -112,24 +112,24 @@
private: // New functions
/**
- * Handles NotifyAccessoryAudioLinkOpenedL() client request.
+ * Handles NotifyAccessoryAudioLinkOpened() client request.
* If leave occurs, the client request is completed with that error code.
*
@@ -112,24 +112,24 @@
/**
- * Handles NotifyAccessoryAudioLinkClosedL() client request.
+ * Handles NotifyAccessoryAudioLinkClosed() client request.
* If leave occurs, the client request is completed with that error code.
*
@@ -182,7 +182,7 @@
void CancelAccessoryAudioLinkClose( const RMessage2& aMessage );
/**
- * Handles NotifyAccessoryAudioLinkOpenedL() client request.
+ * Handles NotifyAccessoryAudioLinkOpened() client request.
* If leave occurs, the client request is completed with that error code.
*
@@ -192,7 +192,7 @@
void CancelNotifyAccessoryAudioLinkOpened( const RMessage2& aMessage );
/**
- * Handles NotifyAccessoryAudioLinkClosedL() client request.
+ * Handles NotifyAccessoryAudioLinkClosed() client request.
* If leave occurs, the client request is completed with that error code.
*
@@ -213,10 +213,10 @@
//Stored AccessoryAudioLinkClose() client request for later completion.
RMessage2 iAccessoryAudioLinkCloseMsg;
- //Stored NotifyAccessoryAudioLinkOpenedL() client request for later completion.
+ //Stored NotifyAccessoryAudioLinkOpened() client request for later completion.
RMessage2 iNotifyAccessoryAudioLinkOpenedMsg;
@@ -213,10 +213,10 @@
RMessage2 iNotifyAccessoryAudioLinkOpenedMsg;
- //Stored NotifyAccessoryAudioLinkClosedL() client request for later completion.
+ //Stored NotifyAccessoryAudioLinkClosed() client request for later completion.
RMessage2 iNotifyAccessoryAudioLinkClosedMsg;
//Thread id of the client-side caller for this subsession
--- a/accessoryservices/accessoryserver/src/Server/AccSrvServerModel.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvServerModel.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -719,17 +719,17 @@
}
// -----------------------------------------------------------------------------
-// CAccSrvServerModel::AddASYThreadIdL
+// CAccSrvServerModel::AddASYThreadId
// -----------------------------------------------------------------------------
//
-void CAccSrvServerModel::AddASYThreadIdL( TUint aThreadID )
+void CAccSrvServerModel::AddASYThreadId( TUint aThreadID )
{
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::AddASYThreadIdL(%d)", aThreadID );
- iRegisteredASYs.AppendL( aThreadID );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::AddASYThreadId(%d)", aThreadID );
+ iRegisteredASYs.Append( aThreadID );
}
// -----------------------------------------------------------------------------
-// CAccSrvServerModel::StoreASYThreadIDL
+// CAccSrvServerModel::StoreASYThreadID
//
// If aThreadID can be found from connected ASYs table (iRegisteredASYs),
// mapping between aUniqueID and aThreadID can be made.
@@ -737,17 +737,17 @@
// all request for that gineric ID.
// -----------------------------------------------------------------------------
//
-void CAccSrvServerModel::StoreASYThreadIDL( TUint aThreadID, TInt aUniqueID )
+void CAccSrvServerModel::StoreASYThreadID( TUint aThreadID, TInt aUniqueID )
{
- COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadIDL(%d %d)", aThreadID, aUniqueID );
+ COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadID(%d %d)", aThreadID, aUniqueID );
if ( KErrNotFound == iRegisteredASYs.Find( aThreadID ) )
{
- COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadIDL - Thread ID is not ASYs" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadID - Thread ID is not ASYs" );
}
else
{
- iASYThreadID.AppendL( aThreadID );
- iASYUniqueID.AppendL( aUniqueID );
+ iASYThreadID.Append( aThreadID );
+ iASYUniqueID.Append( aUniqueID );
}
}
@@ -760,7 +760,7 @@
COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::RemoveASYThreadID(%d)", aUniqueID );
TInt index( iASYUniqueID.Find( aUniqueID ) );
//If index is KErrNotFound, threadIDs are never stored in CAccSrvServerModel::StoreASYThreadIDL()
if ( KErrNotFound != index )
{
iASYThreadID.Remove( index );
@@ -798,20 +798,20 @@
}
// -----------------------------------------------------------------------------
-// CAccSrvServerModel::SetMsgThreadIDFilterL
+// CAccSrvServerModel::SetMsgThreadIDFilter
// -----------------------------------------------------------------------------
//
-void CAccSrvServerModel::SetMsgThreadIDFilterL( TUint aThreadID, TMsgID aMsgID )
+void CAccSrvServerModel::SetMsgThreadIDFilter( TUint aThreadID, TMsgID aMsgID )
{
- COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilterL(%d %d)", aThreadID, aMsgID );
+ COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilter(%d %d)", aThreadID, aMsgID );
TAccSrvThreadIDFilter threadIDFilter;
threadIDFilter.iThreadID = aThreadID;
threadIDFilter.iMsgID = aMsgID;
- iThreadIDFilterArray.AppendL( threadIDFilter );
+ iThreadIDFilterArray.Append( threadIDFilter );
- COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilterL - count=%d - return void", iThreadIDFilterArray.Count() );
+ COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilter - count=%d - return void", iThreadIDFilterArray.Count() );
}
// -----------------------------------------------------------------------------
@@ -863,7 +863,7 @@
else
{
COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - handling index %d", index );
- iCancelledConnectAccessory.AppendL( genericIDArray.GetGenericIDL( index ).UniqueID() );
+ iCancelledConnectAccessory.Append( genericIDArray.GetGenericIDL( index ).UniqueID() );
}
COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - return void" );
@@ -894,7 +894,7 @@
else
{
COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - handling index %d", index );
- iCancelledConnectAccessory.AppendL( genericIDArray.GetGenericIDL( index ).UniqueID() );
+ iCancelledConnectAccessory.Append( genericIDArray.GetGenericIDL( index ).UniqueID() );
}
COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - DeviceAddress - return void" );
@@ -760,7 +760,7 @@
COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::RemoveASYThreadID(%d)", aUniqueID );
TInt index( iASYUniqueID.Find( aUniqueID ) );
- //If index is KErrNotFound, threadIDs are never stored in CAccSrvServerModel::StoreASYThreadIDL()
+ //If index is KErrNotFound, threadIDs are never stored in CAccSrvServerModel::StoreASYThreadID()
if ( KErrNotFound != index )
{
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSubAudioControl.cpp Wed Sep 15 13:36:47 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSubAudioControl.cpp Wed Oct 13 15:58:37 2010 +0300
@@ -121,12 +121,12 @@
}
// -----------------------------------------------------------------------------
-// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL
+// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened
// -----------------------------------------------------------------------------
//
-void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL( const RMessage2& aMessage )
+void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened( const RMessage2& aMessage )
{
- COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL()" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened()" );
iConnectionController->NotificationQueue().RegisterControlMessage( EAccessoryAudioLinkOpened,
this );
@@ -136,24 +136,24 @@
// If message is null, there is no pending request and no filtering needed
if ( !iAccessoryAudioLinkOpenMsg.IsNull() )
{
//NotifyAccessoryAudioLinkOpenedL() notification is filtered
//for AccessoryAudioLinkOpen() caller thread.
//In this case NotifyAccessoryAudioLinkOpenedL() notification
//is ordered after AccessoryAudioLinkOpen() is sent.
- iConnectionController->ServerModel().SetMsgThreadIDFilterL( iCallerThreadID,
+ iConnectionController->ServerModel().SetMsgThreadIDFilter( iCallerThreadID,
EAccessoryAudioLinkOpened );
}
- COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL - return void" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened - return void" );
}
// -----------------------------------------------------------------------------
-// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL
+// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed
// -----------------------------------------------------------------------------
//
-void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL( const RMessage2& aMessage )
+void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed( const RMessage2& aMessage )
{
- COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL()" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed()" );
iConnectionController->NotificationQueue().RegisterControlMessage( EAccessoryAudioLinkClosed,
this );
@@ -162,15 +162,15 @@
// If message is null, there is no pending request and no filtering needed
if ( !iAccessoryAudioLinkCloseMsg.IsNull() )
{
//NotifyAccessoryAudioLinkClosedL() notification is filtered
//for AccessoryAudioLinkClose() caller thread.
//In this case NotifyAccessoryAudioLinkClosedL() notification
//is ordered after AccessoryAudioLinkClose() is sent.
- iConnectionController->ServerModel().SetMsgThreadIDFilterL( iCallerThreadID,
+ iConnectionController->ServerModel().SetMsgThreadIDFilter( iCallerThreadID,
EAccessoryAudioLinkClosed );
}
- COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL - return void" );
+ COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed - return void" );
}
// -----------------------------------------------------------------------------
@@ -219,9 +219,9 @@
// If message is null, there is no pending request and no filtering needed
if ( !iNotifyAccessoryAudioLinkOpenedMsg.IsNull() )
{
//NotifyAccessoryAudioLinkOpenedL notification() is filtered
//for AccessoryAudioLinkOpen() caller thread
- iConnectionController->ServerModel().SetMsgThreadIDFilterL( iCallerThreadID,
+ iConnectionController->ServerModel().SetMsgThreadIDFilter( iCallerThreadID,
EAccessoryAudioLinkOpened );
}
@@ -263,9 +263,9 @@
// If message is null, there is no pending request and no filtering needed
if ( !iNotifyAccessoryAudioLinkClosedMsg.IsNull() )
{
//NotifyAccessoryAudioLinkClosedL() notification is filtered
//for AccessoryAudioLinkClose() caller thread
- iConnectionController->ServerModel().SetMsgThreadIDFilterL(
+ iConnectionController->ServerModel().SetMsgThreadIDFilter(
iCallerThreadID,
EAccessoryAudioLinkClosed );
}
@@ -311,7 +311,7 @@
this );
//AccessoryAudioLinkOpen() request is cancelled
//-> NO filtering needed for NotifyAccessoryAudioLinkOpenedL()
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID,
EAccessoryAudioLinkOpened );
@@ -340,7 +340,7 @@
this );
//AccessoryAudioLinkClose() request is cancelled
//-> NO filtering needed for NotifyAccessoryAudioLinkClosedL()
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID, EAccessoryAudioLinkClosed );
@@ -367,7 +367,7 @@
iConnectionController->NotificationQueue().CancelControlMessage(
EAccessoryAudioLinkOpened, this );
//NotifyAccessoryAudioLinkOpenedL() notification order is cancelled
//-> NO filtering needed for that message
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID, EAccessoryAudioLinkOpened );
@@ -394,7 +394,7 @@
iConnectionController->NotificationQueue().CancelControlMessage(
EAccessoryAudioLinkClosed, this );
//NotifyAccessoryAudioLinkClosedL() notification order is cancelled
//-> NO filtering needed for that message
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID, EAccessoryAudioLinkClosed );
@@ -422,12 +422,12 @@
{
case EAccSrvNotifyAccessoryAudioLinkOpened:
{
- NotifyAccessoryAudioLinkOpenedL( aMessage );
+ NotifyAccessoryAudioLinkOpened( aMessage );
break;
}
case EAccSrvNotifyAccessoryAudioLinkClosed:
{
- NotifyAccessoryAudioLinkClosedL( aMessage );
+ NotifyAccessoryAudioLinkClosed( aMessage );
break;
}
case EAccSrvAccessoryAudioLinkOpen:
@@ -494,7 +494,7 @@
{
if( KErrNone != aErrorCode )
{
//Release NotifyAccessoryAudioLinkOpenedL() filtering in error case.
//BluetoothAudioLinkOpenedNotify() message is never sent in error case
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID,
@@ -511,7 +511,7 @@
{
if( KErrNone != aErrorCode )
{
//Release NotifyAccessoryAudioLinkClosedL() filtering in error case.
//BluetoothAudioLinkClosedNotify() message is never sent in error case
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID,
@@ -526,13 +526,13 @@
case EAccessoryAudioLinkOpened:
{
// Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkOpenedL()
// notification was ordered from the same thread that AccessoryAudioLinkOpen() was called
if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID,
EAccessoryAudioLinkOpened ) )
{
//Complete outstanding NotifyAccessoryAudioLinkOpenedL request
//Notice, This works for single client (Server model can store only one value)
TAccAudioType audioType( iConnectionController->ServerModel().AudioType() );
TAccPolGenericID genericID;
@@ -555,13 +555,13 @@
case EAccessoryAudioLinkClosed:
{
// Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkClosedL()
// notification was ordered from the same thread that AccessoryAudioLinkClose() was called
if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID,
EAccessoryAudioLinkClosed ) )
{
//Complete outstanding NotifyAccessoryAudioLinkClosedL request
//Notice, This works for single client (Server model can store only one value)
TAccAudioType audioType( iConnectionController->ServerModel().AudioType() );
TAccPolGenericID genericID;
@@ -136,24 +136,24 @@
if ( !iAccessoryAudioLinkOpenMsg.IsNull() )
{
- //NotifyAccessoryAudioLinkOpenedL() notification is filtered
+ //NotifyAccessoryAudioLinkOpened() notification is filtered
//for AccessoryAudioLinkOpen() caller thread.
@@ -136,24 +136,24 @@
//for AccessoryAudioLinkOpen() caller thread.
- //In this case NotifyAccessoryAudioLinkOpenedL() notification
+ //In this case NotifyAccessoryAudioLinkOpened() notification
//is ordered after AccessoryAudioLinkOpen() is sent.
@@ -162,15 +162,15 @@
if ( !iAccessoryAudioLinkCloseMsg.IsNull() )
{
- //NotifyAccessoryAudioLinkClosedL() notification is filtered
+ //NotifyAccessoryAudioLinkClosed() notification is filtered
//for AccessoryAudioLinkClose() caller thread.
@@ -162,15 +162,15 @@
//for AccessoryAudioLinkClose() caller thread.
- //In this case NotifyAccessoryAudioLinkClosedL() notification
+ //In this case NotifyAccessoryAudioLinkClosed() notification
//is ordered after AccessoryAudioLinkClose() is sent.
@@ -219,9 +219,9 @@
if ( !iNotifyAccessoryAudioLinkOpenedMsg.IsNull() )
{
- //NotifyAccessoryAudioLinkOpenedL notification() is filtered
+ //NotifyAccessoryAudioLinkOpened notification() is filtered
//for AccessoryAudioLinkOpen() caller thread
@@ -263,9 +263,9 @@
if ( !iNotifyAccessoryAudioLinkClosedMsg.IsNull() )
{
- //NotifyAccessoryAudioLinkClosedL() notification is filtered
+ //NotifyAccessoryAudioLinkClosed() notification is filtered
//for AccessoryAudioLinkClose() caller thread
@@ -311,7 +311,7 @@
this );
//AccessoryAudioLinkOpen() request is cancelled
- //-> NO filtering needed for NotifyAccessoryAudioLinkOpenedL()
+ //-> NO filtering needed for NotifyAccessoryAudioLinkOpened()
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID,
@@ -340,7 +340,7 @@
this );
//AccessoryAudioLinkClose() request is cancelled
- //-> NO filtering needed for NotifyAccessoryAudioLinkClosedL()
+ //-> NO filtering needed for NotifyAccessoryAudioLinkClosed()
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
iCallerThreadID, EAccessoryAudioLinkClosed );
@@ -367,7 +367,7 @@
iConnectionController->NotificationQueue().CancelControlMessage(
EAccessoryAudioLinkOpened, this );
- //NotifyAccessoryAudioLinkOpenedL() notification order is cancelled
+ //NotifyAccessoryAudioLinkOpened() notification order is cancelled
//-> NO filtering needed for that message
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -394,7 +394,7 @@
iConnectionController->NotificationQueue().CancelControlMessage(
EAccessoryAudioLinkClosed, this );
- //NotifyAccessoryAudioLinkClosedL() notification order is cancelled
+ //NotifyAccessoryAudioLinkClosed() notification order is cancelled
//-> NO filtering needed for that message
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -494,7 +494,7 @@
if( KErrNone != aErrorCode )
{
- //Release NotifyAccessoryAudioLinkOpenedL() filtering in error case.
+ //Release NotifyAccessoryAudioLinkOpened() filtering in error case.
//BluetoothAudioLinkOpenedNotify() message is never sent in error case
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -511,7 +511,7 @@
if( KErrNone != aErrorCode )
{
- //Release NotifyAccessoryAudioLinkClosedL() filtering in error case.
+ //Release NotifyAccessoryAudioLinkClosed() filtering in error case.
//BluetoothAudioLinkClosedNotify() message is never sent in error case
iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -526,13 +526,13 @@
case EAccessoryAudioLinkOpened:
{
- // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkOpenedL()
+ // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkOpened()
// notification was ordered from the same thread that AccessoryAudioLinkOpen() was called
if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -526,13 +526,13 @@
EAccessoryAudioLinkOpened ) )
{
- //Complete outstanding NotifyAccessoryAudioLinkOpenedL request
+ //Complete outstanding NotifyAccessoryAudioLinkOpened request
//Notice, This works for single client (Server model can store only one value)
TAccAudioType audioType( iConnectionController->ServerModel().AudioType() );
@@ -555,13 +555,13 @@
case EAccessoryAudioLinkClosed:
{
- // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkClosedL()
+ // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkClosed()
// notification was ordered from the same thread that AccessoryAudioLinkClose() was called
if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -555,13 +555,13 @@
EAccessoryAudioLinkClosed ) )
{
- //Complete outstanding NotifyAccessoryAudioLinkClosedL request
+ //Complete outstanding NotifyAccessoryAudioLinkClosed request
//Notice, This works for single client (Server model can store only one value)
TAccAudioType audioType( iConnectionController->ServerModel().AudioType() );